<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>ConkyCustomizeDialog</name>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="56"/>
        <source>Customize Conky - %1</source>
        <translation>Conky Aanpassen - %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="77"/>
        <source>Launch</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="81"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="83"/>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="106"/>
        <location filename="../src/conkycustomizedialog.cpp" line="186"/>
        <source>Colors</source>
        <translation>Kleuren</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color0</source>
        <translation>Kleur0</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color1</source>
        <translation>Kleur1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color2</source>
        <translation>Kleur2</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color3</source>
        <translation>Kleur3</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color4</source>
        <translation>Kleur4</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color5</source>
        <translation>Kleur5</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color6</source>
        <translation>Kleur6</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color7</source>
        <translation>Kleur7</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color8</source>
        <translation>Kleur8</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color9</source>
        <translation>Kleur9</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="193"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="337"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="713"/>
        <source>Select Color</source>
        <translation>Selecteer Kleur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="819"/>
        <source>Permission Denied</source>
        <translation>Toestemming Geweigerd</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="820"/>
        <source>Cannot write to file: %1
Insufficient permissions.</source>
        <translation>Kan niet schrijven naar bestand: %1
Onvoldoende rechten.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="830"/>
        <source>Write Error</source>
        <translation>Schrijffout</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="830"/>
        <source>Cannot write to file: %1</source>
        <translation>Kan niet schrijven naar bestand: %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="921"/>
        <source>Backup Config File</source>
        <translation>Back-up Configuratiebestand</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="921"/>
        <source>Do you want to preserve the original file?</source>
        <translation>Wil je het originele bestand behouden?</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="945"/>
        <source>Backed Up Config File</source>
        <translation>Geback-upt Configuratiebestand</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="946"/>
        <source>The original configuration was backed up to %1</source>
        <translation>Van de oorspronkelijke configuratie is een back-up gemaakt op %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="948"/>
        <source>Backup Failed</source>
        <translation>Back-up Mislukt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="948"/>
        <source>Failed to create a backup file.</source>
        <translation>Maken van een back-upbestand mislukt.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1029"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1032"/>
        <source>Restore Failed</source>
        <translation>Herstel Mislukt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1029"/>
        <source>Failed to restore from backup file.</source>
        <translation>Kan niet herstellen vanuit back-upbestand.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1032"/>
        <source>Backup file does not exist.</source>
        <translation>Back-upbestand bestaat niet.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1384"/>
        <source>Position</source>
        <translation>Positie</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1391"/>
        <source>Alignment</source>
        <translation>Uitlijning</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1396"/>
        <source>Top Left</source>
        <translation>Linksboven</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1397"/>
        <source>Top Right</source>
        <translation>Rechtsboven</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1398"/>
        <source>Top Middle</source>
        <translation>Midden Boven</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1399"/>
        <source>Bottom Left</source>
        <translation>Linksonder</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1400"/>
        <source>Bottom Right</source>
        <translation>Rechtsonder</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1401"/>
        <source>Bottom Middle</source>
        <translation>Midden Onder</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1402"/>
        <source>Middle Left</source>
        <translation>Midden Links</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1403"/>
        <source>Middle Right</source>
        <translation>Midden Rechts</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1404"/>
        <source>Middle Middle</source>
        <translation>Midden Midden</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1409"/>
        <source>Horizontal Gap</source>
        <translation>Horizontaal Gat</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1410"/>
        <source>[GAP_X] Horizontal distance from window border (in pixels)</source>
        <translation>[GAP_X] Horizontale afstand van vensterrand (in pixels)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1422"/>
        <source>Vertical Gap</source>
        <translation>Verticaal Gat</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1423"/>
        <source>[GAP_Y] Vertical distance from window border (in pixels)</source>
        <translation>[GAP_Y] Verticale afstand vanaf de vensterrand (in pixels)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1435"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1438"/>
        <source>Desktop 1</source>
        <translation>Desktop 1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1439"/>
        <source>All Desktops</source>
        <translation>Alle Desktops</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1451"/>
        <source>Location</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1463"/>
        <source>Width should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>De breedte moet groter zijn dan de inhoud van het venster,
anders heeft deze instelling geen effect.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1467"/>
        <source>Minimum Width</source>
        <translation>Minimale Breedte</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1482"/>
        <source>Height should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>De hoogte moet groter zijn dan de inhoud van het venster,
anders heeft deze instelling geen effect.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1484"/>
        <source>Minimum Height</source>
        <translation>Minimale hoogte</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1498"/>
        <source>Increases the window height by adding empty lines at the end of the Conky config file</source>
        <translation>Verhoogt de vensterhoogte door lege regels toe te voegen aan het einde van het Conky config-bestand</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1499"/>
        <source>Height Padding</source>
        <translation>Hoogte opvulling</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1514"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1527"/>
        <source>Transparency Type</source>
        <translation>Type transparantie</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1532"/>
        <source>Opaque</source>
        <translation>Ondoorzichtig</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1533"/>
        <source>Transparent</source>
        <translation>Transparant</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1534"/>
        <source>Pseudo-Transparent</source>
        <translation>Pseudo-Transparant</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1535"/>
        <source>Semi-Transparent</source>
        <translation>Halfdoorzichtig</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1540"/>
        <source>Opacity (%)</source>
        <translation>Dekking (%)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1541"/>
        <source>Window Opacity

0 = Fully Transparent, 100 = Fully Opaque</source>
        <translation>Vensterdekking

0 = volledig transparant, 100 = volledig ondoorzichtig</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1555"/>
        <source>Background Color</source>
        <translation>Achtergrond Kleur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1560"/>
        <source>Choose Color</source>
        <translation>Kies Kleur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1580"/>
        <source>Setting Type to &quot;Transparent&quot; will make the whole window transparent (including any images). Use &quot;Pseudo-Transparent&quot; if you want the images to be opaque.</source>
        <translation>Als je Type instelt op &quot;Transparant&quot; wordt het hele venster transparant (inclusief alle afbeeldingen). Gebruik &quot;Pseudo-Transparant&quot; als je wilt dat de afbeeldingen ondoorzichtig zijn.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1590"/>
        <source>Setting Type to &quot;Pseudo-Transparent&quot; will make the window transparent but the window will have a shadow. The shadow can be disabled by configuring your window manager.</source>
        <translation>Door Type in te stellen op &quot;Pseudo-Transparent&quot; wordt het venster transparant, maar heeft het venster wel een schaduw. De schaduw kan worden uitgeschakeld door je window manager te configureren.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1601"/>
        <source>Transparency</source>
        <translation>Transparantie</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1612"/>
        <source>Date Format</source>
        <translation>Datum Formaat</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1615"/>
        <source>Day</source>
        <translation>Dag</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1617"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1628"/>
        <source>Long</source>
        <translation>Lang</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1618"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1629"/>
        <source>Short</source>
        <translation>Kort</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1619"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Afgekorte naam, bv. Di</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1626"/>
        <source>Month</source>
        <translation>Maand</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1630"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Afgekorte naam, bv. Okt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1649"/>
        <source>Time Format</source>
        <translation>Tijd Formaat:</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1656"/>
        <source>Format</source>
        <translation>Formaat</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1661"/>
        <source>12 Hour</source>
        <translation>12 Uur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1662"/>
        <source>24 Hour</source>
        <translation>24 Uur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1663"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1678"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Datum &amp;&amp; Tijd</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1691"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1699"/>
        <source>WiFi</source>
        <translation>WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1702"/>
        <source>WiFi Network</source>
        <translation>WiFi Netwerk</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1705"/>
        <source>LAN</source>
        <translation>LAN</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1708"/>
        <source>Wired LAN Network</source>
        <translation>Bekabeld LAN-netwerk</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1722"/>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="2037"/>
        <source>Select Background Color</source>
        <translation>Selecteer Achtergrondkleur</translation>
    </message>
</context>
<context>
    <name>ConkyItemWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Running</source>
        <translation>Actief</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Stopped</source>
        <translation>Gestopt</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="138"/>
        <source>Autostart</source>
        <translation>Autostart</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="140"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="143"/>
        <source>Customize</source>
        <translation>Aanpassen</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="148"/>
        <source>Delete</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="177"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="180"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
</context>
<context>
    <name>ConkyListWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="344"/>
        <source>Total: 0 conkies</source>
        <translation>Totaal: 0 conkies</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="598"/>
        <source>Total: %1 conkies</source>
        <translation>Totaal: %1 conkies</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="601"/>
        <source>Showing: %1 of %2 conkies</source>
        <translation>Tonen: %1 van %2 conkies</translation>
    </message>
</context>
<context>
    <name>ConkyPreviewWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="550"/>
        <source>No Conky Selected</source>
        <translation>Geen Conky Geselecteerd</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="552"/>
        <source>Select a conky from the list to see its preview</source>
        <translation>Selecteer een conky uit de lijst om het voorbeeld te zien</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="571"/>
        <source>Preview image could not be loaded</source>
        <translation>Voorbeeldafbeelding kan niet worden geladen</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="574"/>
        <source>No preview image available</source>
        <translation>Geen voorbeeldafbeelding beschikbaar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="58"/>
        <location filename="../src/mainwindow.cpp" line="849"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="248"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="255"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="270"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="268"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="158"/>
        <source>Loading Conky configurations...</source>
        <translation>Conky configuraties laden...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="188"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="190"/>
        <source>Configure conky search paths</source>
        <translation>Conky zoekpaden configureren</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="192"/>
        <source>Refresh</source>
        <translation>Verversen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="194"/>
        <source>Refresh conky list</source>
        <translation>Conky-lijst vernieuwen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="196"/>
        <source>Start All</source>
        <translation>Alles Starten</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="198"/>
        <source>Start all enabled conkies</source>
        <translation>Start alle ingeschakelde conkies</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="200"/>
        <source>Stop All</source>
        <translation>Alles Stoppen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="202"/>
        <source>Stop all running conkies</source>
        <translation>Stop alle actieve conkies</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="951"/>
        <location filename="../src/mainwindow.cpp" line="995"/>
        <source>Running</source>
        <translation>Actief</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="953"/>
        <location filename="../src/mainwindow.cpp" line="996"/>
        <source>Stopped</source>
        <translation>Gestopt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="210"/>
        <source>Search conky by name...</source>
        <translation>Zoek conky op naam...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="212"/>
        <source>Search conkies by name (Ctrl+F)</source>
        <translation>Zoek conkies op naam (Ctrl+F)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Display help</source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="433"/>
        <location filename="../src/mainwindow.cpp" line="607"/>
        <source>Copy Conky</source>
        <translation>Kopieer Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <location filename="../src/mainwindow.cpp" line="655"/>
        <source>Conky Copied</source>
        <translation>Conky Gekopieerd</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="480"/>
        <source>Conky has been copied to your personal folder for editing:
%1</source>
        <translation>Conky is gekopieerd naar je persoonlijke map om te bewerken:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="482"/>
        <location filename="../src/mainwindow.cpp" line="658"/>
        <source>Copy Failed</source>
        <translation>Kopiëren mislukt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="482"/>
        <location filename="../src/mainwindow.cpp" line="658"/>
        <source>Failed to copy conky to your personal folder.</source>
        <translation>Kopiëren van conky naar je persoonlijke map mislukt.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <source>Delete Conky</source>
        <translation>Conky Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="656"/>
        <source>Conky has been copied to your personal folder for customization:
%1</source>
        <translation>Conky is gekopieerd naar je persoonlijke map voor aanpassingen:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="184"/>
        <source>Previews</source>
        <translation>Voorbeelden</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="186"/>
        <source>Generate preview images for conkies</source>
        <translation>Voorbeeldafbeeldingen genereren voor conkies</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="206"/>
        <location filename="../src/mainwindow.cpp" line="467"/>
        <location filename="../src/mainwindow.cpp" line="643"/>
        <location filename="../src/mainwindow.cpp" line="949"/>
        <location filename="../src/mainwindow.cpp" line="994"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="207"/>
        <source>Filter conkies by running status or location</source>
        <translation>Filter conkies op actiefstatus of locatie</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="429"/>
        <location filename="../src/mainwindow.cpp" line="603"/>
        <source>Enter a name for the copy:</source>
        <translation>Voer een naam in voor de kopie:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="430"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>In order for you to edit and save a conky, it must first be copied to ~/.conky where you have permission.
Enter a name for the copy.</source>
        <translation>Om een conky te kunnen bewerken en opslaan, moet deze eerst gekopieerd worden naar ~/.conky waar je toestemming hebt.
Voer een naam in voor de kopie.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="447"/>
        <location filename="../src/mainwindow.cpp" line="623"/>
        <source>Directory Exists</source>
        <translation>Directory Bestaat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="448"/>
        <location filename="../src/mainwindow.cpp" line="624"/>
        <source>A conky with the name '%1' already exists in your personal folder.
Do you want to overwrite it?</source>
        <translation>Er bestaat al een conky met de naam &apos;%1&apos; in uw persoonlijke map.
Wilt u deze overschrijven?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="515"/>
        <source>Edit Conky</source>
        <translation>Conky bewerken</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="516"/>
        <source>This conky file is read-only and requires administrator privileges to edit.
Do you want to edit it with elevated privileges?</source>
        <translation>Dit conky-bestand is alleen-lezen en vereist beheerdersrechten om te bewerken.
Wil je het bewerken met verhoogde rechten?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="545"/>
        <source>Are you sure you want to delete the conky file:
%1

This action cannot be undone.</source>
        <translation>Weet je zeker dat je het conky-bestand wilt verwijderen:
%1

Deze actie kan niet ongedaan worden gemaakt.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <source>Delete Failed</source>
        <translation>Verwijderen mislukt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <source>Failed to delete conky file:
%1</source>
        <translation>Verwijderen van conky-bestand mislukt:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="665"/>
        <source>Customize Conky</source>
        <translation>Conky Aanpassen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="666"/>
        <source>This conky file is read-only and requires administrator privileges to customize.
Do you want to customize it with elevated privileges?</source>
        <translation>Dit conky-bestand is alleen-lezen en vereist beheerdersrechten om het aan te passen.
Wil je het aanpassen met verhoogde rechten?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Editor Error</source>
        <translation>Bewerkfout</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Cannot start editor for file: %1</source>
        <translation>Kan editor niet starten voor bestand: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="848"/>
        <source>About MX Conky</source>
        <translation>Over MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="850"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="851"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>GUI programma voor configuratie van Conky in MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="854"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="855"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="856"/>
        <location filename="../src/mainwindow.cpp" line="868"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="857"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="879"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="910"/>
        <source>MX Conky Help</source>
        <translation>MX Conky Hulp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="955"/>
        <location filename="../src/mainwindow.cpp" line="997"/>
        <source>Autostart</source>
        <translation>Autostart</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="../src/previewdialog.cpp" line="50"/>
        <source>Generate Preview</source>
        <translation>Voorbeeld Genereren</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="75"/>
        <source>Generate preview images for</source>
        <translation>Voorbeeldafbeeldingen genereren voor</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="78"/>
        <source>Selected Widget</source>
        <translation>Geselecteerde Widget</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="79"/>
        <source>All Widgets with Missing Previews</source>
        <translation>Alle Widgets met Ontbrekende Voorbeelden</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="80"/>
        <source>All Widgets (Overwrite Existing Images)</source>
        <translation>Alle widgets (Bestaande Afbeeldingen Overschrijven)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="85"/>
        <source>No conky is currently selected</source>
        <translation>Er is momenteel geen conky geselecteerd</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="93"/>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="96"/>
        <source>High quality images (PNG)</source>
        <translation>Afbeeldingen van hoge kwaliteit (PNG)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="97"/>
        <source>Generate preview images in PNG format instead of JPEG</source>
        <translation>Voorbeeldafbeeldingen genereren in PNG-indeling in plaats van JPEG</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="114"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="118"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No Items</source>
        <translation>Geen items</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No conky widgets need preview generation.</source>
        <translation>Er hoeven geen conky widgets voorvertoningen te worden gegenereerd.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="151"/>
        <source>Missing Dependency</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="152"/>
        <source>Preview generation requires the GraphicsMagick compatibility tools.
Please install the graphicsmagick-imagemagick-compat package to enable this feature.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="163"/>
        <source>Starting preview generation...</source>
        <translation>Voorbeeldgeneratie starten...</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="167"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="206"/>
        <source>Generating preview for: %1</source>
        <translation>Voorbeeld genereren voor: %1</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="427"/>
        <source>Preview generation complete! Generated %1 previews.</source>
        <translation>Genereren van voorbeelden voltooid! %1 voorbeelden gegenereerd.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="431"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="434"/>
        <source>Preview Generation Complete</source>
        <translation>Voorbeeldgeneratie Voltooid</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="435"/>
        <source>Successfully generated %1 preview images.</source>
        <translation>Met succes %1 voorbeeldafbeeldingen gegenereerd.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="67"/>
        <source>Select Conky Manager config file</source>
        <translation>Selecteer Conky Beheer configuratiebestand</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>You must run this program as normal user</source>
        <translation>U moet dit programma als normale gebruiker uitvoeren</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.cpp" line="40"/>
        <location filename="../src/settingsdialog.cpp" line="62"/>
        <source>Select Conky Directory</source>
        <translation>Selecteer Conky Map</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>MX Conky Settings</source>
        <translation>MX Conky-instellingen</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="91"/>
        <source>Search Paths</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="92"/>
        <source>Autostart</source>
        <translation>Autostart</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="167"/>
        <source>Conky Search Paths</source>
        <translation>Conky Zoekpaden</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="173"/>
        <source>Add Path</source>
        <translation>Pad Toevoegen</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="176"/>
        <source>Remove Path</source>
        <translation>Pad Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="179"/>
        <source>Edit Path</source>
        <translation>Pad Bewerken</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="206"/>
        <source>Autostart Settings</source>
        <translation>Autostart Instellingen</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="209"/>
        <source>Start conky at system startup</source>
        <translation>Conky starten bij het opstarten van het systeem</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="212"/>
        <source>Startup delay (seconds):</source>
        <translation>Opstartvertraging (seconden):</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="95"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="96"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
</context>
</TS>